OptProblem: OptProblem object.

Description

Description

The OptProblem contains all the constants values which define a OptProblem within our MBO Steps. It is an environment and is always pointed at by the OptState.


pday2/mlrMBO_mP documentation built on July 21, 2020, 12:16 a.m.